from enum import Enum

class CmNodeType(Enum):
    Inferred = 'Inferred'
    TextBased = 'TextBased'
